APIProvider class

A class responsible for making API requests using Dio.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request(APIRequestRepresentable request) → Future
Perform an API request based on the provided APIRequestRepresentable.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → APIProvider
Get the singleton instance of APIProvider.
no setter