APIRequestRepresentable class abstract

An abstract class representing an API request with various properties.

Implementers

Constructors

APIRequestRepresentable()

Properties

bodies → dynamic
Request bodies for the API request.
no setter
endpoints → String
Endpoints for the API request.
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
Headers for the API request.
no setter
methods → HTTPMethod
HTTP method for the API request.
no setter
paths → String
Paths for the API request.
no setter
queries → Map<String, String>?
Query parameters for the API request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urls → String
URLs for the API request.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request() → Future
Perform the API request and return the response.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited